
:mod:`pyrcel.distributions`.BaseDistribution
===================================================

.. currentmodule:: pyrcel.distributions

.. autoclass:: BaseDistribution
   :members:
   :undoc-members:

   
   .. automethod:: __init__
   
